﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Globalization;
using System.Threading;
using System.IO;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace ColumnFetch
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		ShapeFileFeatureLayer myLayer;

		public MainWindow()
		{
			InitializeComponent();

			Thread.CurrentThread.CurrentCulture = CultureInfo.InvariantCulture;

			// to change accordingly...
			string shapefileDirectory = @"c:\_divers\thinkgeo\bugs\ColumnFetch\Shapefile";

			myLayer = new ShapeFileFeatureLayer(Path.Combine(shapefileDirectory, "UGA_region_2.shp"));

			ManagedProj4Projection proj = new ManagedProj4Projection();
			string prjString = System.IO.File.ReadAllText(Path.Combine(shapefileDirectory, "UGA_region_2.prj"));
			string proj4String = Proj4Projection.ConvertPrjToProj4(prjString);
			proj.InternalProjectionParametersString = proj4String;
			proj.ExternalProjectionParametersString = ManagedProj4Projection.GetEpsgParametersString(4326);

			myLayer.FeatureSource.Projection = proj;
			myLayer.RequireIndex = false;
			myLayer.IsVisible = true;

			myLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Transparent, GeoColor.FromArgb(100, GeoColor.SimpleColors.Green));
			myLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

			myLayer.Open();
			
			wpfMap.MapUnit = GeographyUnit.DecimalDegree;

			wpfMap.Overlays.Clear();

			LayerOverlay layerOverlay = new LayerOverlay();
			layerOverlay.TransitionEffect = TransitionEffect.None;
			layerOverlay.TileType = TileType.SingleTile;
			layerOverlay.DrawingExceptionMode = DrawingExceptionMode.DrawException;

			layerOverlay.Layers.Add("layer", myLayer);

			wpfMap.Overlays.Add("Layers", layerOverlay);

			myLayer.FeatureSource.CustomColumnFetch += FeatureSource_CustomColumnFetch;
			wpfMap.Loaded += wpfMap_Loaded;
		}

		void wpfMap_Loaded(object sender, RoutedEventArgs e)
		{
			myLayer.FeatureSource.GetAllFeatures(new List<string>() { "unknownColumn" });
			//myLayer.QueryTools.GetAllFeatures(new List<string>() { "unknownColumn" });
		}

		void FeatureSource_CustomColumnFetch(object sender, CustomColumnFetchEventArgs e)
		{
			e.ColumnValue = "0";
		}
	}
}
